<?php
Class AdminView
{
  /***************************************************************************
   * Customer User Profile Fields                                            *
   * *************************************************************************/
  public function add_stripe_customer_id_to_user( $user )
  {
    ?>
      <h3><?php _e('Stripe', 'atomicbroadcast'); ?></h3>
      <table class="form-table">
        <tr>
          <th>
            <label for="_stripe_customer_id">
              <?php _e('Stripe Customer ID', '_stripe_customer_id'); ?>
            </label>
          </th>
          <td>
            <input type="text"
                   name="_stripe_customer_id"
                     id="_stripe_customer_id"
                  value="<?php echo esc_attr( get_the_author_meta(
                                  '_stripe_customer_id', $user->ID ) ); ?>"
	                class="regular-text" /><br />
            <span class="description">
	            <?php _e('Customer ID used by Stripe.', '_stripe_customer_id'); ?>
            </span>
          </td>
        </tr>
      </table>
    <?php
  }
 /******************************************************
  * Create a form to store the various keys generated  *
  * by Stripe.                                         *
  *                                                    *
  * -------------------------------------------------- *
  * | Check to Run in Test Mode | test_mode_checkbox | *
  * -------------------------------------------------- *
  * | Enter Test Secret Key     | test_secret_key    | *
  * -------------------------------------------------- *
  * | Enter Test Public Key     | test_public_key    | *
  * -------------------------------------------------- *
  * | Enter Live Secret Key     | live_secret_key    | *
  * -------------------------------------------------- *
  * | Enter Live Public Key     | live_public_key    | *
  * -------------------------------------------------- *
  *                                                    *
  *****************************************************/
  /***************************************************************************
   * render_options_page()                                                   *
   * *************************************************************************/
  public function render_options_page()
  {
   $stripe_options = get_option( 'stripe_settings' );
    ob_start();
?>
      <div class="wrap">
        <h2>Stripe Settings</h2>
<?php
        // Show the upgrade button if they haven't already paid.
        if (!isset($stripe_options['payment'])
                || $stripe_options['payment'] !== 'paid'
        ){
          self::upgrade_section();
       }
?>
        <form id="stripe_settings_form" method="post" action="options.php">
          <?php settings_fields('stripe_settings_group'); ?>
          <h3>Credit Card Processing</h3>
          <table id="stripe_mode" class="form-table">
<?php
            self::radio_button_option('Select mode of operation:',
              'test_mode', 'Test Mode', 'Live Mode', $stripe_options );
?>
          </table>
          <h3>Stripe API Keys</h3>
          <table id="stripe_keys" class="form-table">
<?php // Test Keys
            self::text_option( 'Test Secret', 'test_secret_key',
              'Paste your secret test key.', $stripe_options );
            self::text_option( 'Test Publishable', 'test_publishable_key',
              'Paste your publishable test key here.', $stripe_options );
            if (isset($stripe_options['payment'])
                  && ($stripe_options['payment'] == 'paid')
            ){  // Live Keys
              self::text_option( 'Live Secret', 'live_secret_key',
                'Paste your live secret key', $stripe_options );
              self::text_option( 'Live Publishable', 'live_publishable_key',
                'Paste your live publishable key', $stripe_options );
            }
            self::payment( $stripe_options );
?>
          </table>
          <h3>Sift Science API Keys</h3>
          <table id="sift_science_keys" class="form-table">
<?php
            self::text_option( 'Sandbox Javascript Snippet Key', 'sandbox_sift_science_js',
              'Paste your Sift Science Sandbox Javascript Snippet Key', $stripe_options);
            self::text_option( 'Sandbox REST API Key', 'sandbox_sift_science_rest',
              'Paste your Sift Science Sandbox REST API Key', $stripe_options);
?>
          </table>
          <table class="form-table unfinished">
            <tbody>
<?php
            self::checkbox( 'Allow Recurring', 'recurring',
              'Allow Recurring Payments?', $stripe_options );
            self::checkbox( 'One Time Sign-Up Fee', 'one_time_fee',
              'charge a signup fee if checked', $stripe_options );
            self::text_option( 'Fee Amount', 'fee_amount', '', $stripe_options );
?>
            </tbody>
          </table>
        <p class="submit">
          <input id="submit_stripe_options" type="submit"
                 class="button-primary" value="Save Options" />
        </p>
      </form>
<?php
    echo ob_get_clean();
  }
  /***************************************************************************
   * define form elements                                                    *
   * *************************************************************************/
  /************************************************
   * $radio_button_option() - radio buttons to set the plugin *
   *              to test mode or live mode       *
   ************************************************/
  public function radio_button_option( $description, $key,
                                       $option1, $option2, $stripe_options )
  {
    $radio_button_option = isset( $stripe_options[$key] )
                                ? $stripe_options[$key] : '' ;
    ob_start();
    ?>
    <tr>
      <th><? echo $description; ?></th>
      <td>
        <input 
          type="radio"
          name="stripe_settings[<?echo $key; ?>]"
          value="1"
          <?php checked($radio_button_option, 1);?>
        >Test Mode
        <input
          type="radio"
          name="stripe_settings[<? echo $key; ?>]"
          value="0"
          <?php checked($radio_button_option, 0);?>
        >Live Mode<br />
      </td>
    </tr>
    <?php
    echo ob_get_clean();
  }
  /***************************************************************************
   * text_option( $heading, $key, $label='' )                                *
   * *************************************************************************/
  public function text_option( $heading, $key, $label='', $stripe_options )
  {
    $text_option = isset( $stripe_options[$key] ) ? $stripe_options[$key] : '';
    ob_start();
    ?>
      <tr>
        <th><? echo $heading; ?></th>
        <td>
          <input id="stripe_settings[<? echo $key; ?>]" 
                 name="stripe_settings[<? echo $key; ?>]" 
                 type="text" class="regular-text" 
                 value="<?php echo $text_option; ?>"
          />
          <label class="description"
                 for="stripe_settings[<? echo $key; ?>]"
          ><? echo $label; ?></label>
        </td>
      </tr>
    <?php
    echo( ob_get_clean() );
  }
  /***************************************************************************
   * checkbox( $heading, $key, $label='' )                                   *
   * *************************************************************************/
  public function checkbox( $heading, $key, $label='', $stripe_options )
  {
    $checked = isset( $stripe_options[$key] )
                    ? $stripe_options[$key]: "false";
    ob_start();
    ?>
      <tr>
        <th><? echo $heading; ?></th>
        <td>
          <input id="stripe_settings[<? echo $key; ?>]" 
                 name="stripe_settings[<? echo $key; ?>]" 
                 type="checkbox" value="1" <?php checked( 1, $checked ); ?> />
          <label class="description"
                 for="stripe_settings[<? echo $key; ?>]"><?php echo $label; ?>
          </label>
        </td>
      </tr>
    <?php
    echo ob_get_clean();
  }
  public function payment( $stripe_options )
  {
    $payment_input_type = ( ADMIN_TEST ? 'text' : 'hidden' );

    ob_start();
    ?>
      <input
        id="stripe_settings[payment]"
        name="stripe_settings[payment]"
        type="<?php echo($payment_input_type) ?>"
        class="regular-text"
        value="<?php echo $stripe_options['payment']; ?>"
      >
    <?php
    echo ob_get_clean();
  }
  /***************************************************************************
   * upgrade_section()                                                       *
   * *************************************************************************/
  public function upgrade_section()
  {
    ob_start();
    ?>
      <h3>Upgrade to Accept Live Payments</h3>
      <form action="http://www.atomicbroadcast.net/press-pay/">
        <input type=submit value="Upgrade Now!" class="button-primary">
      </form>
    <?php
    echo ob_get_clean();
  }
}
?>
