<?php
/*****************************************************************************
 * Plugin Name: PressPay
 * Plugin URI: http://atomicbroadcast.net/
 * Description: A plugin to easily turn any WordPress blog into a webstore.
 * Author: Andrew Dixon
 * Author URI: http://atomicbroadcast.net
 * Version: 1.6
 *****************************************************************************/
/**********************************
* constants and globals
**********************************/
if (!defined( 'STRIPE_BASE_URL' )) {
	define( 'STRIPE_BASE_URL', plugin_dir_url( __FILE__ ) );
}
if (!defined( 'STRIPE_BASE_DIR' )) {
	define( 'STRIPE_BASE_DIR', dirname( __FILE__ ) );
}
if (!defined( 'PRESS_PAY_TRANSACTION_TABLE' )) {
  global $wpdb;
  define( 'PRESS_PAY_TRANSACTION_TABLE', $wpdb->prefix . 'press_pay_transactions' );
}
if (!defined('PRESS_PAY_CUSTOMER_TABLE')) {
  global $wpdb;
  define( 'PRESS_PAY_CUSTOMER_TABLE', $wpdb->prefix . 'press_pay_customers' );
}
// Setup Database Tables.
require_once( STRIPE_BASE_DIR . '/db/migrations/migrate.php' );
add_action( 'plugins_loaded', 'press_pay_migrate_database' );

// Get options from Settings Page
$stripe_options = get_option('stripe_settings');
/**********************************
* includes
**********************************/
include( STRIPE_BASE_DIR . '/lib/Mixin.php' );
include( STRIPE_BASE_DIR . '/app/model/debug.model.php' );
include( STRIPE_BASE_DIR . '/app/controller/listener/listener.c.php' );

if (is_admin()) {
  require_once( STRIPE_BASE_DIR . '/app/controller/admin.controller.php' );
  $adminController = new AdminController;
  // BUG: cannot peform the following actions in AdminController::__construct()
  //      when these commands are executed here using the instance
  //      $adminController instead of the instance $this in __construct()
  //      the user defined settings are registered, Stripe Settings is added to
  //      the admin menu, and AdminController::upgrade() is registered with the
  //      core WordPress system.
  $adminController->addMixin( new DebugModel() );
  $adminController->addMixin( new AdminView() );
  $adminController->addMixin( new AdminModel() );
  add_action( 'admin_init', array( $adminController, 'register_settings' ));
  add_action( 'admin_menu', array( $adminController, 'menu_setup' ));
  add_action( 'admin_init', array( $adminController, 'upgrade' ));
  add_action( 'show_user_profile', array( $adminController,
    'add_stripe_customer_id_to_user' ));
  add_action( 'edit_user_profile', array( $adminController,
    'add_stripe_customer_id_to_user' ));
  add_action( 'personal_options_update', array( $adminController,
    'save_stripe_customer_id' ) );
  add_action( 'edit_user_profile_update', array( $adminController,
    'save_stripe_customer_id' ) );
  $plugin = plugin_basename(__FILE__);
  add_filter('plugin_action_links_$plugin', array( $adminController,
    'settings_link' ) );
} else {
  require_once(STRIPE_BASE_DIR . '/app/controller/presspay.controller.php');
  require_once(STRIPE_BASE_DIR . '/app/controller/checkout.controller.php');
  require_once(STRIPE_BASE_DIR . '/app/controller/email.controller.php');
  require_once(STRIPE_BASE_DIR . '/app/model/press_pay_customer.php');
  require_once(STRIPE_BASE_DIR . '/app/model/press_pay_transaction.php');
  $pressPay = new PressPayController;
  $checkoutController = new CheckoutController;
  // start session for sift science
  add_action( 'wp_loaded', 'sift_science_session' );
}

function sift_science_session() {
  if (!session_id()) {
    session_start();
  }
}
?>
